pecos.qeccs.color\_488.gates
============================

.. automodule:: pecos.qeccs.color_488.gates











   .. rubric:: Classes

   .. autosummary::

      GateIdentity
      GateInitPlus
      GateInitZero
